@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 # flake8: noqa
-__author__ = 'Nick Ficano'
-__email__ = 'nficano@gmail.com'
-__version__ = '0.6.0'
+__author__ = 'Wassim Salib '
+__email__ = 'wassim87@gmail.com'
+__version__ = '3.4.0'
 
-from .aws_lambda import deploy, invoke, init, build, cleanup_old_versions
+from .aws_lambda import deploy, deploy_s3, invoke, init, build, upload, cleanup_old_versions
 
 # Set default logging handler to avoid "No handler found" warnings.
 import logging
